@@ -21,4 +21,4 @@ TODO:
 
 from .processes import *
 from .parallelizer import Parallelize, CanceledError
-from .remoteproxy import proxy
\ No newline at end of file
+from .remoteproxy import proxy, ClosedError, NoResultError
